Documentation
¶
Overview ¶
Package v1 is the v1 version of the API. +groupName=netconf.openshift-telco.io
Package v1 contains API Schema definitions for the netconf v1 API group +kubebuilder:object:generate=true +groupName=netconf.openshift-telco.io
Index ¶
- Variables
- type Commit
- type CommitList
- type CommitSpec
- type CreateSubscription
- func (in *CreateSubscription) DeepCopy() *CreateSubscription
- func (in *CreateSubscription) DeepCopyInto(out *CreateSubscription)
- func (in *CreateSubscription) DeepCopyObject() runtime.Object
- func (obj *CreateSubscription) GetMountPointNamespacedName(mountpoint string) string
- func (obj *CreateSubscription) GetNamespacedName() string
- type CreateSubscriptionList
- type CreateSubscriptionSpec
- type DependsOn
- type EditConfig
- type EditConfigList
- type EditConfigSpec
- type EstablishSubscription
- func (in *EstablishSubscription) DeepCopy() *EstablishSubscription
- func (in *EstablishSubscription) DeepCopyInto(out *EstablishSubscription)
- func (in *EstablishSubscription) DeepCopyObject() runtime.Object
- func (obj *EstablishSubscription) GetMountPointNamespacedName(mountpoint string) string
- func (obj *EstablishSubscription) GetNamespacedName() string
- type EstablishSubscriptionList
- type EstablishSubscriptionSpec
- type Get
- type GetConfig
- type GetConfigList
- type GetConfigSpec
- type GetList
- type GetSpec
- type KafkaSink
- type Lock
- type LockList
- type LockSpec
- type MountPoint
- type MountPointList
- type MountPointSpec
- type RPC
- type RPCList
- type RPCSpec
- type RPCStatus
- type Unlock
- type UnlockList
- type UnlockSpec
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "netconf.openshift-telco.io", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Commit ¶
type Commit struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CommitSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
Commit is the Schema for the commits API
func (*Commit) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Commit.
func (*Commit) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Commit) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Commit) GetMountPointNamespacedName ¶
func (*Commit) GetNamespacedName ¶
type CommitList ¶
type CommitList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Commit `json:"items"`
}
CommitList contains a list of Commit
func (*CommitList) DeepCopy ¶
func (in *CommitList) DeepCopy() *CommitList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CommitList.
func (*CommitList) DeepCopyInto ¶
func (in *CommitList) DeepCopyInto(out *CommitList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CommitList) DeepCopyObject ¶
func (in *CommitList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CommitSpec ¶
type CommitSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// If this Commit operation should occur after another operation, specify the other operation here.
DependsOn DependsOn `json:"dependsOn,omitempty"`
}
CommitSpec defines the desired state of Commit
func (*CommitSpec) DeepCopy ¶
func (in *CommitSpec) DeepCopy() *CommitSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CommitSpec.
func (*CommitSpec) DeepCopyInto ¶
func (in *CommitSpec) DeepCopyInto(out *CommitSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CreateSubscription ¶
type CreateSubscription struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CreateSubscriptionSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
CreateSubscription is the Schema for the createsubscriptions API
func (*CreateSubscription) DeepCopy ¶
func (in *CreateSubscription) DeepCopy() *CreateSubscription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CreateSubscription.
func (*CreateSubscription) DeepCopyInto ¶
func (in *CreateSubscription) DeepCopyInto(out *CreateSubscription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CreateSubscription) DeepCopyObject ¶
func (in *CreateSubscription) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*CreateSubscription) GetMountPointNamespacedName ¶
func (obj *CreateSubscription) GetMountPointNamespacedName(mountpoint string) string
func (*CreateSubscription) GetNamespacedName ¶
func (obj *CreateSubscription) GetNamespacedName() string
type CreateSubscriptionList ¶
type CreateSubscriptionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []CreateSubscription `json:"items"`
}
CreateSubscriptionList contains a list of CreateSubscription
func (*CreateSubscriptionList) DeepCopy ¶
func (in *CreateSubscriptionList) DeepCopy() *CreateSubscriptionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CreateSubscriptionList.
func (*CreateSubscriptionList) DeepCopyInto ¶
func (in *CreateSubscriptionList) DeepCopyInto(out *CreateSubscriptionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CreateSubscriptionList) DeepCopyObject ¶
func (in *CreateSubscriptionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CreateSubscriptionSpec ¶
type CreateSubscriptionSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Defines the stream to subscribe to
Stream string `json:"stream,omitempty"`
// Defines the start-time to listen to changes.
StartTime string `json:"startTime,omitempty"`
// Defines the time when to stop listen to changes.
StopTime string `json:"stopTime,omitempty"`
// Used to forward received notification to kafka
KafkaSink KafkaSink `json:"kafkaSink,omitempty"`
}
CreateSubscriptionSpec defines the desired state of CreateSubscription
func (*CreateSubscriptionSpec) DeepCopy ¶
func (in *CreateSubscriptionSpec) DeepCopy() *CreateSubscriptionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CreateSubscriptionSpec.
func (*CreateSubscriptionSpec) DeepCopyInto ¶
func (in *CreateSubscriptionSpec) DeepCopyInto(out *CreateSubscriptionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DependsOn ¶
type DependsOn struct {
// Any of the Kind supported by netconf.openshift-telco.io/v1 Group
Kind string `json:"kind,omitempty"`
// The name of the object, which will be checked for within the same namespace
Name string `json:"name,omitempty"`
}
DependsOn allows to specify a dependency for the operation to execute. If such dependency is not met, and/or if the underlying dependency isn't reporting success, the operation will fail.
func (*DependsOn) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DependsOn.
func (*DependsOn) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EditConfig ¶
type EditConfig struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EditConfigSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
EditConfig is the Schema for the editconfigs API
func (*EditConfig) DeepCopy ¶
func (in *EditConfig) DeepCopy() *EditConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EditConfig.
func (*EditConfig) DeepCopyInto ¶
func (in *EditConfig) DeepCopyInto(out *EditConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EditConfig) DeepCopyObject ¶
func (in *EditConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EditConfig) GetMountPointNamespacedName ¶
func (obj *EditConfig) GetMountPointNamespacedName(mountpoint string) string
func (*EditConfig) GetNamespacedName ¶
func (obj *EditConfig) GetNamespacedName() string
type EditConfigList ¶
type EditConfigList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EditConfig `json:"items"`
}
EditConfigList contains a list of EditConfig
func (*EditConfigList) DeepCopy ¶
func (in *EditConfigList) DeepCopy() *EditConfigList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EditConfigList.
func (*EditConfigList) DeepCopyInto ¶
func (in *EditConfigList) DeepCopyInto(out *EditConfigList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EditConfigList) DeepCopyObject ¶
func (in *EditConfigList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EditConfigSpec ¶
type EditConfigSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Defined the operation to perform. Default to `merge`.
//See https://datatracker.ietf.org/doc/html/rfc6241#section-7.2 for supported operations.
// +kubebuilder:default:="merge"
Operation string `json:"operation,omitempty"`
// Identify the datastore against which the operation should be performed. Default to `candidate`.
// +kubebuilder:default:="candidate"
Target string `json:"target,omitempty"`
// Define the XML payload to sent
XML string `json:"xml"`
// If this EditConfig operation should occur after another operation, specify the other operation here.
DependsOn DependsOn `json:"dependsOn,omitempty"`
// Whether to lock the specified datastore before doing the edit-config
// +kubebuilder:default:=false
Lock bool `json:"lock,omitempty"`
// Whether to commit the changes.
// +kubebuilder:default:=false
Commit bool `json:"commit,omitempty"`
// Whether to unlock the specified datastore before doing the edit-config
// +kubebuilder:default:=false
Unlock bool `json:"unlock,omitempty"`
}
EditConfigSpec defines the desired state of EditConfig
func (*EditConfigSpec) DeepCopy ¶
func (in *EditConfigSpec) DeepCopy() *EditConfigSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EditConfigSpec.
func (*EditConfigSpec) DeepCopyInto ¶
func (in *EditConfigSpec) DeepCopyInto(out *EditConfigSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EstablishSubscription ¶
type EstablishSubscription struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EstablishSubscriptionSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
EstablishSubscription is the Schema for the establishsubscriptions API
func (*EstablishSubscription) DeepCopy ¶
func (in *EstablishSubscription) DeepCopy() *EstablishSubscription
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EstablishSubscription.
func (*EstablishSubscription) DeepCopyInto ¶
func (in *EstablishSubscription) DeepCopyInto(out *EstablishSubscription)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EstablishSubscription) DeepCopyObject ¶
func (in *EstablishSubscription) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EstablishSubscription) GetMountPointNamespacedName ¶
func (obj *EstablishSubscription) GetMountPointNamespacedName(mountpoint string) string
func (*EstablishSubscription) GetNamespacedName ¶
func (obj *EstablishSubscription) GetNamespacedName() string
type EstablishSubscriptionList ¶
type EstablishSubscriptionList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []EstablishSubscription `json:"items"`
}
EstablishSubscriptionList contains a list of EstablishSubscription
func (*EstablishSubscriptionList) DeepCopy ¶
func (in *EstablishSubscriptionList) DeepCopy() *EstablishSubscriptionList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EstablishSubscriptionList.
func (*EstablishSubscriptionList) DeepCopyInto ¶
func (in *EstablishSubscriptionList) DeepCopyInto(out *EstablishSubscriptionList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EstablishSubscriptionList) DeepCopyObject ¶
func (in *EstablishSubscriptionList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EstablishSubscriptionSpec ¶
type EstablishSubscriptionSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Defines the `<establish-subscription` RPC to sent
XML string `json:"xml"`
// Used to forward received notification to kafka
KafkaSink KafkaSink `json:"kafkaSink,omitempty"`
}
EstablishSubscriptionSpec defines the desired state of EstablishSubscription
func (*EstablishSubscriptionSpec) DeepCopy ¶
func (in *EstablishSubscriptionSpec) DeepCopy() *EstablishSubscriptionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EstablishSubscriptionSpec.
func (*EstablishSubscriptionSpec) DeepCopyInto ¶
func (in *EstablishSubscriptionSpec) DeepCopyInto(out *EstablishSubscriptionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Get ¶
type Get struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GetSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
Get is the Schema for the gets API
func (*Get) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Get.
func (*Get) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Get) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Get) GetMountPointNamespacedName ¶
func (*Get) GetNamespacedName ¶
type GetConfig ¶
type GetConfig struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec GetConfigSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
GetConfig is the Schema for the getconfigs API
func (*GetConfig) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetConfig.
func (*GetConfig) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GetConfig) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*GetConfig) GetMountPointNamespacedName ¶
func (*GetConfig) GetNamespacedName ¶
type GetConfigList ¶
type GetConfigList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []GetConfig `json:"items"`
}
GetConfigList contains a list of GetConfig
func (*GetConfigList) DeepCopy ¶
func (in *GetConfigList) DeepCopy() *GetConfigList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetConfigList.
func (*GetConfigList) DeepCopyInto ¶
func (in *GetConfigList) DeepCopyInto(out *GetConfigList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GetConfigList) DeepCopyObject ¶
func (in *GetConfigList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GetConfigSpec ¶
type GetConfigSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Identify the datastore against which the operation should be performed. Default to `running`.
// +kubebuilder:default:="running"
Target string `json:"target,omitempty"`
}
GetConfigSpec defines the desired state of GetConfig
func (*GetConfigSpec) DeepCopy ¶
func (in *GetConfigSpec) DeepCopy() *GetConfigSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetConfigSpec.
func (*GetConfigSpec) DeepCopyInto ¶
func (in *GetConfigSpec) DeepCopyInto(out *GetConfigSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GetList ¶
type GetList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Get `json:"items"`
}
GetList contains a list of Get
func (*GetList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetList.
func (*GetList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GetList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GetSpec ¶
type GetSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Define the filter to apply; see more https://datatracker.ietf.org/doc/html/rfc6241#page-20
FilterType string `json:"filterType,omitempty"`
// Define the XML payload to sent
FilterXML string `json:"filterXML,omitempty"`
}
GetSpec defines the desired state of Get
func (*GetSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GetSpec.
func (*GetSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KafkaSink ¶
type KafkaSink struct {
Enabled bool `json:"enabled"`
Topic string `json:"topic"`
TransportType string `json:"transportType"`
Broker string `json:"broker"`
Partition int `json:"partition"`
}
func (*KafkaSink) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KafkaSink.
func (*KafkaSink) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Lock ¶
type Lock struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LockSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
Lock is the Schema for the locks API
func (*Lock) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Lock.
func (*Lock) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Lock) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Lock) GetMountPointNamespacedName ¶
func (*Lock) GetNamespacedName ¶
type LockList ¶
type LockList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Lock `json:"items"`
}
LockList contains a list of Lock
func (*LockList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LockList.
func (*LockList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LockList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type LockSpec ¶
type LockSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Identify the datastore against which the operation should be performed. Default to `candidate`.
// +kubebuilder:default:="candidate"
Target string `json:"target,omitempty"`
}
LockSpec defines the desired state of Lock
func (*LockSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LockSpec.
func (*LockSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MountPoint ¶
type MountPoint struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec MountPointSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
MountPoint is the Schema for the mountPoints API
func (*MountPoint) DeepCopy ¶
func (in *MountPoint) DeepCopy() *MountPoint
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MountPoint.
func (*MountPoint) DeepCopyInto ¶
func (in *MountPoint) DeepCopyInto(out *MountPoint)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MountPoint) DeepCopyObject ¶
func (in *MountPoint) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*MountPoint) GetMountPointNamespacedName ¶
func (obj *MountPoint) GetMountPointNamespacedName(mountpoint string) string
func (*MountPoint) GetNamespacedName ¶
func (obj *MountPoint) GetNamespacedName() string
type MountPointList ¶
type MountPointList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []MountPoint `json:"items"`
}
MountPointList contains a list of MountPoint
func (*MountPointList) DeepCopy ¶
func (in *MountPointList) DeepCopy() *MountPointList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MountPointList.
func (*MountPointList) DeepCopyInto ¶
func (in *MountPointList) DeepCopyInto(out *MountPointList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MountPointList) DeepCopyObject ¶
func (in *MountPointList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MountPointSpec ¶
type MountPointSpec struct {
// Represents the Netconf server to establish a session with.
// By default, port `830` is used. If you need to use another port,
// provide the target in the following format: `<host>:<port>`.
Target string `json:"target"`
// The username to use to authenticate
Username string `json:"username"`
// The password to use to authenticate
Password string `json:"password"`
// Whether to apply timeout while attempting the connection, expressed in second.
// By default, set to `15` seconds. Put `0` for no timeout.
// +kubebuilder:default:=15
Timeout int32 `json:"timeout,omitempty"`
// This is to instruct the NETCONF client to advertise additional capabilities
AdditionalCapabilities []string `json:"additionalCapabilities,omitempty"`
}
MountPointSpec defines the desired state of MountPoint
func (*MountPointSpec) DeepCopy ¶
func (in *MountPointSpec) DeepCopy() *MountPointSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MountPointSpec.
func (*MountPointSpec) DeepCopyInto ¶
func (in *MountPointSpec) DeepCopyInto(out *MountPointSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RPC ¶
type RPC struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec RPCSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
RPC is the Schema for the rpcs API
func (*RPC) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RPC.
func (*RPC) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RPC) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*RPC) GetMountPointNamespacedName ¶
func (*RPC) GetNamespacedName ¶
type RPCList ¶
type RPCList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []RPC `json:"items"`
}
RPCList contains a list of RPC
func (*RPCList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RPCList.
func (*RPCList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RPCList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type RPCSpec ¶
type RPCSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Define the XML payload to sent
XML string `json:"xml"`
}
RPCSpec defines the desired state of RPC
func (*RPCSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RPCSpec.
func (*RPCSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RPCStatus ¶
type RPCStatus struct {
// +patchMergeKey=type
// +patchStrategy=merge
// +listType=map
// +listMapKey=type
Conditions []metav1.Condition `json:"conditions,omitempty" patchStrategy:"merge" patchMergeKey:"type"`
// Either `success` or `failed`
Status string `json:"status,omitempty"`
// Provides the received RPC reply
RpcReply string `json:"rpcReply,omitempty"`
// Provide the list of supported capabilities
Capabilities []string `json:"capabilities,omitempty"`
// In case of a notification, keep track of the subscription-id
SubscriptionID string `json:"subscriptionID,omitempty"`
}
func (*RPCStatus) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RPCStatus.
func (*RPCStatus) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*RPCStatus) GetConditions ¶
func (*RPCStatus) SetConditions ¶
type Unlock ¶
type Unlock struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec UnlockSpec `json:"spec,omitempty"`
RPCStatus `json:"status,omitempty"`
}
Unlock is the Schema for the unlocks API
func (*Unlock) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Unlock.
func (*Unlock) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Unlock) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Unlock) GetMountPointNamespacedName ¶
func (*Unlock) GetNamespacedName ¶
type UnlockList ¶
type UnlockList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Unlock `json:"items"`
}
UnlockList contains a list of Unlock
func (*UnlockList) DeepCopy ¶
func (in *UnlockList) DeepCopy() *UnlockList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UnlockList.
func (*UnlockList) DeepCopyInto ¶
func (in *UnlockList) DeepCopyInto(out *UnlockList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*UnlockList) DeepCopyObject ¶
func (in *UnlockList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type UnlockSpec ¶
type UnlockSpec struct {
// Defines the NETCONF session to use
MountPoint string `json:"mountPoint"`
// Timeout defines the timeout for the NETCONF transaction
// defaults to 1 seconds
// +kubebuilder:default:=1
Timeout int32 `json:"timeout,omitempty"`
// Identify the datastore against which the operation should be performed. Default to `candidate`.
// +kubebuilder:default:="candidate"
Target string `json:"target,omitempty"`
// If this Unlock operation should occur after another operation, specify the other operation here.
DependsOn DependsOn `json:"dependsOn,omitempty"`
}
UnlockSpec defines the desired state of Unlock
func (*UnlockSpec) DeepCopy ¶
func (in *UnlockSpec) DeepCopy() *UnlockSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UnlockSpec.
func (*UnlockSpec) DeepCopyInto ¶
func (in *UnlockSpec) DeepCopyInto(out *UnlockSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.